:mod:`animanager.anidb` --- AniDB API bindings
==============================================

:mod:`animanager.anidb.http` --- AniDB HTTP API tools
-----------------------------------------------------

.. automodule:: animanager.anidb.http
   :members:

:mod:`animanager.anidb.titles` --- AniDB titles API
---------------------------------------------------

.. automodule:: animanager.anidb.titles

   .. autoclass:: TitleSearcher
      :members:

:mod:`animanager.anidb.anime` --- AniDB anime API
-------------------------------------------------

.. automodule:: animanager.anidb.anime
   :members:
